#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsec-numbers
version:              0.1.0
visibility:           public
id:                   parsec-numbers-0.1.0-3DpUQ2w4KxcFj9LWjOgXQe
key:                  parsec-numbers-0.1.0-3DpUQ2w4KxcFj9LWjOgXQe
license:              BSD-3-Clause
maintainer:           chr.maeder@web.de
author:               chr.maeder@web.de
stability:            experimental
synopsis:             Utilities for parsing numbers from strings
description:
    parsec-numbers provides the number parsers without the need to
    use a large (and unportable) token parser

category:             Parsing
abi:                  5295b88ecfd4bd0d490797cf8822955c
exposed:              True
exposed-modules:      Text.ParserCombinators.Parsec.Number
import-dirs:          /usr/lib/ghc-8.10.5/site-local/parsec-numbers-0.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/parsec-numbers-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/parsec-numbers-0.1.0
hs-libraries:         HSparsec-numbers-0.1.0-3DpUQ2w4KxcFj9LWjOgXQe
depends:              base-4.14.2.0 parsec-3.1.14.0
haddock-interfaces:
    /usr/share/doc/haskell-parsec-numbers/html/parsec-numbers.haddock

haddock-html:         /usr/share/doc/haskell-parsec-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

